[totem/gnome-2-28] Use the giosrc when reading from gvfs archive mounts



commit a5f860b52abe4b138f097c49fc29304b3df41ad7
Author: Bastien Nocera <hadess hadess net>
Date:   Tue Jan 5 10:52:22 2010 +0100

    Use the giosrc when reading from gvfs archive mounts
    
    Reading that same file through FUSE fails.
    
    https://bugzilla.gnome.org/show_bug.cgi?id=597448

 src/backend/bacon-video-widget-gst-0.10.c |    8 ++++++--
 1 files changed, 6 insertions(+), 2 deletions(-)
---
diff --git a/src/backend/bacon-video-widget-gst-0.10.c b/src/backend/bacon-video-widget-gst-0.10.c
index efceb53..17222bf 100644
--- a/src/backend/bacon-video-widget-gst-0.10.c
+++ b/src/backend/bacon-video-widget-gst-0.10.c
@@ -3265,8 +3265,12 @@ bacon_video_widget_open (BaconVideoWidget * bvw,
   /* this allows non-URI type of files in the thumbnailer and so on */
   file = g_file_new_for_commandline_arg (mrl);
 
-  /* Only use the URI when FUSE isn't available for a file */
-  path = g_file_get_path (file);
+  /* Only use the URI when FUSE isn't available for a file
+   * or we're trying to read from an archive */
+  if (g_file_has_uri_scheme (file, "archive") != FALSE)
+    path = NULL;
+  else
+    path = g_file_get_path (file);
   if (path) {
     bvw->priv->mrl = g_filename_to_uri (path, NULL, NULL);
     g_free (path);



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]